cgexplore.forcefields.ForcedSystem
==================================

.. currentmodule:: cgexplore.forcefields

.. autoclass:: ForcedSystem
   :members:
   :inherited-members:
   :undoc-members:
   :show-inheritance:


   
   
   .. rubric:: Methods

   .. autosummary::
      :nosignatures:
   
      ~ForcedSystem.get_openmm_system
      ~ForcedSystem.get_openmm_topology
   
   

   
   
   .. rubric:: Attributes

   .. autosummary::
   
      ~ForcedSystem.molecule
      ~ForcedSystem.forcefield_terms
      ~ForcedSystem.vdw_bond_cutoff
   
   